Learn R Programming

thermocouple (version 1.0.0)

EquationThermocouplesTypeB: Equation for Calculating Voltage from Temperature for Thermocouples Type B

Description

EquationThermocouplesTypeB Calculates Voltage from Temperature for Thermocouples Type B

EquationThermocouplesTypeB Calculates Voltage from Temperature for Thermocouples Type E

EquationThermocouplesTypeB Calculates Voltage from Temperature for Thermocouples Type J

EquationThermocouplesTypeB Calculates Voltage from Temperature for Thermocouples Type K

EquationThermocouplesTypeB Calculates Voltage from Temperature for Thermocouples Type N

EquationThermocouplesTypeB Calculates Voltage from Temperature for Thermocouples Type R

EquationThermocouplesTypeB Calculates Voltage from Temperature for Thermocouples Type S

EquationThermocouplesTypeB Calculates Voltage from Temperature for Thermocouples Type T

Usage

EquationThermocouplesTypeB(vT)

Arguments

vT
Vector with temperatures (C)

Value

  • VVoltage (mV)

source

Kerlin, T.W., 1999 Practical Thermocouple Thermometry International Society of Automation (ISA)

References

Kerlin, T.W., 1999 Practical Thermocouple Thermometry International Society of Automation (ISA)