Learn R Programming

thermocouple (version 1.0.0)

InverseEquationThermocouplesTypeB: Equation for Calculating Temperature from Voltage for Thermocouples Type B

Description

InverseEquationThermocouplesTypeB Calculates Voltage from Temperature for Thermocouples Type B

InverseEquationThermocouplesTypeB Calculates Voltage from Temperature for Thermocouples Type E

InverseEquationThermocouplesTypeB Calculates Voltage from Temperature for Thermocouples Type J

InverseEquationThermocouplesTypeB Calculates Voltage from Temperature for Thermocouples Type K

InverseEquationThermocouplesTypeB Calculates Voltage from Temperature for Thermocouples Type N

InverseEquationThermocouplesTypeB Calculates Voltage from Temperature for Thermocouples Type R

InverseEquationThermocouplesTypeB Calculates Voltage from Temperature for Thermocouples Type S

InverseEquationThermocouplesTypeB Calculates Voltage from Temperature for Thermocouples Type T

Usage

InverseEquationThermocouplesTypeB(vV)

Arguments

vV
Vector with voltages (C)

Value

  • TTemperature (C)

source

Kerlin, T.W., 1999 Practical Thermocouple Thermometry International Society of Automation (ISA)

References

Kerlin, T.W., 1999 Practical Thermocouple Thermometry International Society of Automation (ISA)