coefficientsThermocoupleTypeB: Polynomial Equation Coefficients for Voltage to Temperature for Thermocouple Type B
Description
coefficientsThermocoupleTypeB Coefficients for Voltage to Temperature for Thermocouple Type BUsage
coefficientsThermocoupleTypeB
source
Kerlin, T.W., 1999
Practical Thermocouple Thermometry
International Society of Automation (ISA)References
Kerlin, T.W., 1999
Practical Thermocouple Thermometry
International Society of Automation (ISA)Examples
Run this codedata(coefficientsThermocoupleTypeB)
str(coefficientsThermocoupleTypeB)
Run the code above in your browser using DataLab